@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Michael Ossmann <mike@ossmann.com>
+ * Copyright 2013-2022 Great Scott Gadgets <info@greatscottgadgets.com>
  *
  * This file is part of HackRF.
  *
@@ -27,11 +27,13 @@
 #include "gpio.h"
 
 typedef struct jtag_gpio_t {
-	gpio_t gpio_tms;
 	gpio_t gpio_tck;
+#ifndef PRALINE
+	gpio_t gpio_tms;
 	gpio_t gpio_tdi;
 	gpio_t gpio_tdo;
-#ifdef HACKRF_ONE
+#endif
+#if (defined HACKRF_ONE || defined PRALINE)
 	gpio_t gpio_pp_tms;
 	gpio_t gpio_pp_tdo;
 #endif
@@ -52,11 +54,10 @@ void cpld_jtag_release(jtag_t* const jtag);
  * contents of the buffer has been streamed to the CPLD the given
  * refill_buffer callback will be called. */
 int cpld_jtag_program(
-		jtag_t* const jtag,
-        const uint32_t buffer_length,
-        unsigned char* const buffer,
-        refill_buffer_cb refill
-);
+	jtag_t* const jtag,
+	const uint32_t buffer_length,
+	unsigned char* const buffer,
+	refill_buffer_cb refill);
 unsigned char cpld_jtag_get_next_byte(void);
 
-#endif//__CPLD_JTAG_H__
+#endif //__CPLD_JTAG_H__
