@@ -1,5 +1,6 @@
 /*
- * Copyright 2012 Will Code? (TODO: Proper attribution)
+ * Copyright 2012-2022 Great Scott Gadgets <info@greatscottgadgets.com>
+ * Copyright 2012 Will Code <willcode4@gmail.com>
  * Copyright 2014 Jared Boone <jared@sharebrained.com>
  *
  * This file is part of HackRF.
@@ -32,46 +33,51 @@
 #include <string.h>
 #include "max2837.h"
 #include "max2837_regs.def" // private register def macros
+#include "selftest.h"
 
 /* Default register values. */
-static const uint16_t max2837_regs_default[MAX2837_NUM_REGS] = { 
-	0x150,   /* 0 */
-	0x002,   /* 1 */
-	0x1f4,   /* 2 */
-	0x1b9,   /* 3 */
-	0x00a,   /* 4 */
-	0x080,   /* 5 */
-	0x006,   /* 6 */
-	0x000,   /* 7 */
-	0x080,   /* 8 */
-	0x018,   /* 9 */
-	0x058,   /* 10 */
-	0x016,   /* 11 */
-	0x24f,   /* 12 */
-	0x150,   /* 13 */
-	0x1c5,   /* 14 */
-	0x081,   /* 15 */
-	0x01c,   /* 16 */
-	0x155,   /* 17 */
-	0x155,   /* 18 */
-	0x153,   /* 19 */
-	0x241,   /* 20 */
+static const uint16_t max2837_regs_default[MAX2837_NUM_REGS] = {
+	0x150, /* 0 */
+	0x002, /* 1:  data sheet says 0x002 but read 0x1c2 */
+	0x1f4, /* 2 */
+	0x1b9, /* 3 */
+	0x00a, /* 4 */
+	0x080, /* 5 */
+	0x006, /* 6 */
+	0x000, /* 7 */
+	0x080, /* 8 */
+	0x018, /* 9 */
+	0x058, /* 10 */
+	0x016, /* 11 */
+	0x24f, /* 12 */
+	0x150, /* 13 */
+	0x1c5, /* 14 */
+	0x081, /* 15 */
+	0x01c, /* 16 */
+	0x155, /* 17 */
+	0x155, /* 18 */
+	0x153, /* 19 */
+	0x241, /* 20 */
 	/*
 	 * Charge Pump Common Mode Enable bit (0) of register 21 must be set or TX
 	 * does not work.  Page 1 of the SPI doc says not to set it (0x02c), but
 	 * page 21 says it should be set by default (0x02d).
 	 */
-	0x02d,   /* 21 */
-	0x1a9,   /* 22 */
-	0x24f,   /* 23 */
-	0x180,   /* 24 */
-	0x100,   /* 25 */
-	0x3ca,   /* 26 */
-	0x3e3,   /* 27 */
-	0x0c0,   /* 28 */
-	0x3f0,   /* 29 */
-	0x080,   /* 30 */
-	0x000 }; /* 31 */
+	0x02d,  /* 21 */
+	0x1a9,  /* 22 */
+	0x24f,  /* 23 */
+	0x180,  /* 24 */
+	0x100,  /* 25:  data sheet says 0x100 but read 0x10a */
+	0x3ca,  /* 26 */
+	0x3e3,  /* 27:  data sheet says 0x100 but read 0x3f3 */
+	0x0c0,  /* 28 */
+	0x3f0,  /* 29 */
+	0x080,  /* 30:  data sheet says 0x080 but read 0x092 */
+	0x000}; /* 31:  data sheet says 0x000 but read 0x1ae */
+
+static const uint8_t max2837_regs_skip_verify[] = {1, 25, 27, 30, 31};
+
+static uint16_t max2837_read(max2837_driver_t* const drv, uint8_t r);
 
 /* Set up all registers according to defaults specified in docs. */
 static void max2837_init(max2837_driver_t* const drv)
@@ -84,6 +90,28 @@ static void max2837_init(max2837_driver_t* const drv)
 
 	/* Write default register values to chip. */
 	max2837_regs_commit(drv);
+
+	/* Read back registers to verify. */
+	selftest.max283x_readback_total_registers = MAX2837_NUM_REGS;
+	for (int r = 0; r < MAX2837_NUM_REGS; r++) {
+		for (unsigned int i = 0; i < sizeof(max2837_regs_skip_verify); i++) {
+			if (max2837_regs_skip_verify[i] == r) {
+				goto next;
+			}
+		}
+		uint16_t value = max2837_read(drv, r);
+		if (value != drv->regs[r]) {
+			selftest.max283x_readback_bad_value = value;
+			selftest.max283x_readback_expected_value = drv->regs[r];
+			break;
+		}
+next:
+		selftest.max283x_readback_register_count = r + 1;
+	}
+
+	if (selftest.max283x_readback_register_count < MAX2837_NUM_REGS) {
+		selftest.report.pass = false;
+	}
 }
 
 /*
@@ -93,7 +121,7 @@ static void max2837_init(max2837_driver_t* const drv)
 void max2837_setup(max2837_driver_t* const drv)
 {
 	max2837_init(drv);
-	
+
 	/* Use SPI control instead of B1-B7 pins for gain settings. */
 	set_MAX2837_TXVGA_GAIN_SPI_EN(drv, 1);
 	set_MAX2837_TXVGA_GAIN_MSB_SPI_EN(drv, 1);
@@ -119,13 +147,15 @@ void max2837_setup(max2837_driver_t* const drv)
 	max2837_regs_commit(drv);
 }
 
-static uint16_t max2837_read(max2837_driver_t* const drv, uint8_t r) {
+static uint16_t max2837_read(max2837_driver_t* const drv, uint8_t r)
+{
 	uint16_t value = (1 << 15) | (r << 10);
 	spi_bus_transfer(drv->bus, &value, 1);
 	return value & 0x3ff;
 }
 
-static void max2837_write(max2837_driver_t* const drv, uint8_t r, uint16_t v) {
+static void max2837_write(max2837_driver_t* const drv, uint8_t r, uint16_t v)
+{
 	uint16_t value = (r << 10) | (v & 0x3ff);
 	spi_bus_transfer(drv->bus, &value, 1);
 }
@@ -153,18 +183,20 @@ static inline void max2837_reg_commit(max2837_driver_t* const drv, uint8_t r)
 void max2837_regs_commit(max2837_driver_t* const drv)
 {
 	int r;
-	for(r = 0; r < MAX2837_NUM_REGS; r++) {
+	for (r = 0; r < MAX2837_NUM_REGS; r++) {
 		if ((drv->regs_dirty >> r) & 0x1) {
 			max2837_reg_commit(drv, r);
 		}
 	}
 }
 
-void max2837_set_mode(max2837_driver_t* const drv, const max2837_mode_t new_mode) {
+void max2837_set_mode(max2837_driver_t* const drv, const max2837_mode_t new_mode)
+{
 	drv->set_mode(drv, new_mode);
 }
 
-max2837_mode_t max2837_mode(max2837_driver_t* const drv) {
+max2837_mode_t max2837_mode(max2837_driver_t* const drv)
+{
 	return drv->mode;
 }
 
@@ -210,29 +242,27 @@ void max2837_set_frequency(max2837_driver_t* const drv, uint32_t freq)
 	if (freq < 2400000000U) {
 		band = MAX2837_LOGEN_BSW_2_3;
 		lna_band = MAX2837_LNAband_2_4;
-	}
-	else if (freq < 2500000000U) {
+	} else if (freq < 2500000000U) {
 		band = MAX2837_LOGEN_BSW_2_4;
 		lna_band = MAX2837_LNAband_2_4;
-	}
-	else if (freq < 2600000000U) {
+	} else if (freq < 2600000000U) {
 		band = MAX2837_LOGEN_BSW_2_5;
 		lna_band = MAX2837_LNAband_2_6;
-	}
-	else {
+	} else {
 		band = MAX2837_LOGEN_BSW_2_6;
 		lna_band = MAX2837_LNAband_2_6;
 	}
 
 	/* ASSUME 40MHz PLL. Ratio = F*(4/3)/40,000,000 = F/30,000,000 */
+	freq += (30000000 >> 21); /* round to nearest frequency */
 	div_int = freq / 30000000;
 	div_rem = freq % 30000000;
 	div_frac = 0;
 	div_cmp = 30000000;
-	for( i = 0; i < 20; i++) {
+	for (i = 0; i < 20; i++) {
 		div_frac <<= 1;
-		div_cmp >>= 1;
-		if (div_rem > div_cmp) {
+		div_rem <<= 1;
+		if (div_rem >= div_cmp) {
 			div_frac |= 0x1;
 			div_rem -= div_cmp;
 		}
@@ -259,6 +289,7 @@ typedef struct {
 	uint32_t ft;
 } max2837_ft_t;
 
+// clang-format off
 static const max2837_ft_t max2837_ft[] = {
 	{  1750000, MAX2837_FT_1_75M },
 	{  2500000, MAX2837_FT_2_5M },
@@ -278,6 +309,7 @@ static const max2837_ft_t max2837_ft[] = {
 	{ 28000000, MAX2837_FT_28M },
 	{        0, 0 },
 };
+//clang-format on
 
 uint32_t max2837_set_lpf_bandwidth(max2837_driver_t* const drv, const uint32_t bandwidth_hz) {
 	const max2837_ft_t* p = max2837_ft;
@@ -326,8 +358,9 @@ bool max2837_set_lna_gain(max2837_driver_t* const drv, const uint32_t gain_db) {
 }
 
 bool max2837_set_vga_gain(max2837_driver_t* const drv, const uint32_t gain_db) {
-	if( (gain_db & 0x1) || gain_db > 62)/* 0b11111*2 */
+	if( (gain_db & 0x1) || gain_db > 62) {/* 0b11111*2 */
 		return false;
+}
 		
 	set_MAX2837_VGA(drv, 31-(gain_db >> 1) );
 	max2837_reg_commit(drv, 5);
