@@ -1,4 +1,5 @@
 /*
+ * Copyright 2012-2022 Great Scott Gadgets <info@greatscottgadgets.com>
  * Copyright 2012 Jared Boone
  * Copyright 2013 Benjamin Vernoux
  *
@@ -31,6 +32,10 @@ typedef enum {
 	RF_PATH_DIRECTION_OFF,
 	RF_PATH_DIRECTION_RX,
 	RF_PATH_DIRECTION_TX,
+#ifdef PRALINE
+	RF_PATH_DIRECTION_TX_CALIBRATION,
+	RF_PATH_DIRECTION_RX_CALIBRATION,
+#endif
 } rf_path_direction_t;
 
 typedef enum {
@@ -69,6 +74,13 @@ typedef struct rf_path_t {
 	gpio_t gpio_tx_amp;
 	gpio_t gpio_rx_lna;
 #endif
+#ifdef PRALINE
+	gpio_t gpio_tx_en;
+	gpio_t gpio_mix_en_n;
+	gpio_t gpio_lpf_en;
+	gpio_t gpio_rf_amp_en;
+	gpio_t gpio_ant_bias_en_n;
+#endif
 } rf_path_t;
 
 void rf_path_pin_setup(rf_path_t* const rf_path);
@@ -81,4 +93,4 @@ void rf_path_set_filter(rf_path_t* const rf_path, const rf_path_filter_t filter)
 void rf_path_set_lna(rf_path_t* const rf_path, const uint_fast8_t enable);
 void rf_path_set_antenna(rf_path_t* const rf_path, const uint_fast8_t enable);
 
-#endif/*__RFPATH_H__*/
+#endif /*__RFPATH_H__*/
