@@ -1,4 +1,5 @@
 /*
+ * Copyright 2014-2022 Great Scott Gadgets <info@greatscottgadgets.com>
  * Copyright (C) 2014 Jared Boone, ShareBrained Technology, Inc.
  *
  * This file is part of HackRF.
@@ -33,6 +34,7 @@
 
 typedef struct ssp_config_t {
 	ssp_datasize_t data_bits;
+	ssp_cpol_cpha_t spi_mode;
 	uint8_t serial_clock_rate;
 	uint8_t clock_prescale_rate;
 	gpio_t gpio_select;
@@ -41,6 +43,9 @@ typedef struct ssp_config_t {
 void spi_ssp_start(spi_bus_t* const bus, const void* const config);
 void spi_ssp_stop(spi_bus_t* const bus);
 void spi_ssp_transfer(spi_bus_t* const bus, void* const data, const size_t count);
-void spi_ssp_transfer_gather(spi_bus_t* const bus, const spi_transfer_t* const transfers, const size_t count);
+void spi_ssp_transfer_gather(
+	spi_bus_t* const bus,
+	const spi_transfer_t* const transfers,
+	const size_t count);
 
-#endif/*__SPI_SSP_H__*/
+#endif /*__SPI_SSP_H__*/
